Attribute VB_Name = "modFunction"
Option Explicit
'****************************************************************************
'*
'*          MTM/SCR Series communication demo software
'*              Copyright(c) Neuron Corporation
'*              Version 0.6 Beta     Date:   06/28/2000
'*
'*          Development Language    : Visual Basic 5.0
'*          ActiveX Control         : Microsoft Comm Control 5.0 (MSComm.ocx)
'*
'*          Project file name       : DemoMTMSCR.vbp [proDemoMTMSCR]
'*          Form module file name   : Main.frm       [frmMain]
'*          Common module file name : Function.bas   [modFunction]
'*                                  : Resource.bas   [modResource]
'*
'*          Supported model : MTM-4xx/MTM-5xx Series
'*                            MSA-4xx/MSA-5xx Series
'*                            CT-7xx-5051/CT-8xx-5051 Series
'*                            SCR-5xxN/SCR-9xxN Series
'*                            CH-4xx Series
'*
'****************************************************************************
'*
'*          This file : Function.bas  [modFunction]
'*                      Wide use function module
'*
'****************************************************************************

'---------------------------------------------------------------------------
'     [MSComm.Settings] Property setting function procedure
'       input   SourceParam :User definition variable at [CommParameterType]
'       Output              :Result string
'---------------------------------------------------------------------------
Public Function GetCommSettings(SourceParam As CommParameterType) As String
    Dim TempStr As String
    On Error GoTo ErrorHandler
    TempStr = ""
    TempStr = LTrim(Str(SourceParam.Baudrate)) & ","
    Select Case SourceParam.Parity
    Case 0
        TempStr = TempStr & "n" & ","
    Case 1
        TempStr = TempStr & "o" & ","
    Case 2
        TempStr = TempStr & "e" & ","
    End Select
    TempStr = TempStr & LTrim(Str(SourceParam.BitLength)) & "," & LTrim(Str(SourceParam.StopBit))
    GetCommSettings = TempStr
    Exit Function
ErrorHandler:
    Res = MsgBox(Err.Description, vbCritical, "Warning")
End Function

'---------------------------------------------------------------------------
'       BCC calculation check function on received data
'           input   Source  :Received data
'           Output          :Result check (True/False)
'---------------------------------------------------------------------------
Public Function CheckBCC(Source As String) As Boolean
    Dim TempStr As String
    Dim BCCStr As String
    Dim BccStart As Integer
    On Error GoTo ErrorHandler
    
    If CommParam.STXEnable = 1 Then                     'STX exist check
        Select Case CommParam.BCCRange                  'BCC start position check
        Case 1
            BccStart = 1                                'Set position on STX
        Case 2
            BccStart = Len(CommParam.STX) + 1           'Set position on next STX
        End Select
    Else
        BccStart = 1                                    'Set position on STX
    End If
           
    Select Case CommParam.BCCByte                       'BCC length check
    Case 0                                              'case of no BCC
        CheckBCC = True
        Exit Function
    Case 1                                              'case of 1 byte BCC
        TempStr = Mid(Source, 1, Len(Source) - 1)
        BCCStr = Right(Source, 1)
    Case 2                                              'case of 2 byte BCC
        TempStr = Source
        If Right(TempStr, 1) = vbCr Then TempStr = Left(TempStr, Len(TempStr) - 1)
        TempStr = Mid(TempStr, 1, Len(TempStr) - 2)
        BCCStr = Right(TempStr, 2)
    End Select
    
    If SetBCC(TempStr, BccStart, 0, CommParam.BCCByte) = Source Then ' Comparison BCC
        CheckBCC = True
    Else
        CheckBCC = False
    End If
    Exit Function
ErrorHandler:
    Res = MsgBox(Err.Description, vbCritical, "Warning")
End Function

'---------------------------------------------------------------------------
'       BCC calculation function procedure
'       Input   Source      :Calculate string source
'               StartPos    :BCC calculate start position1:STX, 2:STX Next)
'               EndPos      :BCC calculate end position0:ETX, 1:Data end)
'               BccByte     :BCC byte length (1:1 byte BCC, 2:2 byte BCC)
'       Output              :Add BCC string
'---------------------------------------------------------------------------
Public Function SetBCC(Source As String, StartPos As Integer, EndPos As Integer, BCCByte As Byte) As String
    Dim i As Integer
    Dim Bcc As Byte
    Dim WorkStr As String
    On Error GoTo ErrorHandler
    
    Bcc = 0
    For i = StartPos To Len(Source) - EndPos
       Bcc = Bcc Xor Asc(Mid(Source, i, 1))             'Calculate BCC: XOR
    Next i
    Select Case BCCByte                                 'Check BCC length
    Case 1                                              '1 byte BCC
        SetBCC = Source & Chr(Bcc)
    Case 2                                              '2 byte BCC
        If Bcc < 10 Then
            WorkStr = "0" & Hex(Bcc)
        Else
            WorkStr = Hex(Bcc)
        End If
        WorkStr = Chr(Asc(Mid(WorkStr, 1, 1))) & Chr(Asc(Mid(WorkStr, 2, 1)))
        SetBCC = Source & WorkStr & vbCr                'Add CR character
    End Select
    
    Exit Function
ErrorHandler:
    Res = MsgBox(Err.Description, vbCritical, "Warning")
End Function


'---------------------------------------------------------------------------
'       Change character type function procedure (ASII type or HEX type)
'       Input   Source  :Source string
'               Mode    :Change mode ("HEX":HEX mode, "ASCII":ASCII mode)
'       Output          :Result string
'---------------------------------------------------------------------------
Public Function ChangeCharType(Source As String, Mode As String) As String
    Dim SourceStr As String
    Dim TempStr As String
    Dim DunpStr As String
    Dim S As String * 1
    Dim WorkStr As String * 2
    Dim i As Integer, j As Integer
    On Error GoTo ErrorHandler
    
    Select Case Mode
    Case "HEX"                                          'HEX mode
        TempStr = ""
        WorkStr = ""
        For i = 1 To Len(Source)                        'Change character
            S = Mid(Source, i, 1)
            If Asc(S) < &H10 Then WorkStr = "0" & Hex(Asc(S)) Else WorkStr = Hex(Asc(S))
            TempStr = TempStr & " " & WorkStr
        Next i
        ChangeCharType = Trim(TempStr)
  
    Case "ASCII"                                        'ASCII mode
        SourceStr = Source
        SourceStr = ReplaceString(SourceStr, Chr$(0), Chr$(1))
                                                    'Replace Null with viewable character.
        SourceStr = ReplaceString(SourceStr, vbCr, Chr$(1))
                                                    'Replace CR with viewable character.
        ChangeCharType = SourceStr
        
    End Select
    Exit Function
ErrorHandler:
    Res = MsgBox(Err.Description, vbCritical, "Warning")
End Function

'---------------------------------------------------------------------------
'       Replace string function procedure
'       Input   Source  :Source string
'               Target  :Target string
'               Change  :Replace string
'       Output          :Result string
'---------------------------------------------------------------------------
Public Function ReplaceString(Source As String, Target As String, Change As String) As String
    Dim TempStr As String
    Dim WorkStr As String
    Dim LenTarget As Integer
    Dim P As Integer
    
    On Error GoTo ErrorHandler
    
    If InStr(Source, Target) = 0 Then                 'If target not found, return source
        ReplaceString = Source
        Exit Function
    End If
    TempStr = Source
    LenTarget = Len(Target)
    WorkStr = ""
    Do While InStr(TempStr, Target) <> 0              'Replace until no exist target
        P = InStr(TempStr, Target)
        If LenTarget = Len(Change) Then               'Case of Same length
            Mid(TempStr, P, LenTarget) = Change
        Else                                          'Case of different length
            WorkStr = WorkStr & Mid(TempStr, 1, P - 1) & Change
            P = P + LenTarget
            TempStr = Mid(TempStr, P, Len(TempStr) - (P - 1))
        End If
    Loop
    ReplaceString = WorkStr + TempStr
 
    Exit Function
ErrorHandler:
    Res = MsgBox(Err.Description, vbCritical, "Warning")
End Function

'---------------------------------------------------------------------------
'       Set send string block function procedure (Add STX,ETX,BCC)
'       Input   Source  :Source string
'       Output          :Result string
'---------------------------------------------------------------------------
Public Function SetSendBlock(Source As String) As String
    Dim TempStr As String
    Dim BccStart As Integer
    On Error GoTo ErrorHandler
    
    TempStr = Source
    If CommParam.STXEnable = 1 Then                     'Case of STX exist
        TempStr = CommParam.STX & TempStr               'Add STX
        Select Case CommParam.BCCRange
        Case 1                                          'Case of 1 byte BCC
            BccStart = 1
        Case 2                                          'Case of 2 byte BCC
            BccStart = Len(CommParam.STX) + 1
        End Select
    Else
        BccStart = 1
    End If
    
    Select Case CommParam.ETXEnable
    Case 1                                              'Case ETX exist
        TempStr = TempStr & CommParam.ETX               'Add ETX
    Case 2                                              'Case ETX is CR+LF
        TempStr = TempStr & vbCrLf                      'Add CR+LF
    End Select
                                                        'Add BCC
    If CommParam.BCCByte > 0 Then TempStr = SetBCC(TempStr, BccStart, 0, CommParam.BCCByte)
    
    SetSendBlock = TempStr
    Exit Function
ErrorHandler:
    Res = MsgBox(Err.Description, vbCritical, "Warning")
End Function

