Attribute VB_Name = "modResorce"
Option Explicit
'****************************************************************************
'*
'*          MTM/SCR Series communication demo software
'*              Copyright(c) Neuron Corporation
'*              Version 0.6 Beta     Date:   06/28/2000
'*
'*          Development Language    : Visual Basic 5.0
'*          ActiveX Control         : Microsoft Comm Control 5.0 (MSComm.ocx)
'*
'*          Project file name       : DemoMTMSCR.vbp [proDemoMTMSCR]
'*          Form module file name   : Main.frm       [frmMain]
'*          Common module file name : Function.bas   [modFunction]
'*                                  : Resource.bas   [modResource]
'*
'*          Supported model : MTM-4xx/MTM-5xx Series
'*                            MSA-4xx/MSA-5xx Series
'*                            CT-7xx-5051/CT-8xx-5051 Series
'*                            SCR-5xxN/SCR-9xxN Series
'*                            CH-4xx Series
'*
'****************************************************************************
'*
'*          This file : Resource.bas   [modResource]
'*                      Command codes and application messages module
'*
'****************************************************************************

'---------------------------------------------------------------------------
'           Communication parameter user type declaration
'---------------------------------------------------------------------------
Type CommParameterType
    Port As Integer                 'Port number
    Baudrate As Integer             'Baud rate          [bit/sec]
    BitLength As Byte               'Bit length
    Parity As Byte                  'Parity             [0:NONE, 1:ODD, 2:EVEN]
    StopBit As Byte                 'Stop bit           [1:1bit, 2:2bit, 3:1.5bit]
    RTSEnable As Byte               'RTS line setting   [0:OFF, 1:ON]
    DTREnable As Byte               'DTR line setting   [0:OFF, 1:ON]
    CTSControl As Byte              'CTS line control   [0:no control, 1:control]
    DSRControl As Byte              'DSR line control   [0:no control, 1:control]
    STXEnable As Byte               'STX eneble         [0:no STX, 1:STX]
    ETXEnable As Byte               'ETX enable         [0:no ETX, 1:ETX, 2:CR+LF]
    STX As String                   'STX code
    US As String                    'US code
    ETX As String                   'ETX code
    BCCByte As Byte                 'BCC length
    BCCRange As Byte                'BCC calculate start position [1:STX, 2:STX Next]
    Password As String * 6          'EEPROM open password [6 digit]
    TimeOut As Integer              'Receive waiting time [msec]
End Type

'---------------------------------------------------------------------------
'       Public variable declaration
'---------------------------------------------------------------------------
Public CommParam As CommParameterType       'User type definition
Public Res As Integer                       'Result error message value
Public ACK As String * 1                    'ACK code
Public NAK As String * 1                    'NAK code
Public CAN As String * 1                    'CAN code
Public DLE As String * 1                    'DLE code
Public ENQ As String * 1                    'ENQ code
Public EOT As String * 1                    'EOT code


'---------------------------------------------------------------------------
'       MTM/SCR command code and response code declaration
'           Model   :MTM-4xx,MTM-5xx,MSA-4xx,MSA-5xx series protocol
'                   :CT-7xx-5051,CT-8xx-5051 series protocol
'                   :SCR-5xxN,SCR-9xxN series protocol
'                   :CH-4xx series protocol
'
'           Command data block  [ STX+HED+(PRAM)+(DATA)+ETX+BCC ]      HED: Header of Command
'           Response data block [  STX+HED+{PRAM+DATA}+ETX+BCC ]       HED: Header of Response
'           Control line : CTS/RTS no control (default)
'           StopBitFPbit default
'---------------------------------------------------------------------------
Public Const CMD_Read = "CRC"                       'Read command
Public Const CMD_Write = "CWC"                      'Write command
Public Const CMD_Read_InsertFront = "CRG"           'Read command in insert front on CH-4xx
Public Const CMD_Write_InsertFront = "CWG"          'Write command in insert front on CH-4xx
Public Const CMD_CardPosition_EjectFront = "CHF"    'Card processing end command to eject front
Public Const CMD_CardPosition_EjectRear = "CHR"     'Card processing end command to eject rear
Public Const CMD_CardPosition_Inside = "CHS"        'Card processing end command to inside unit
Public Const CMD_CardPosition_HoldFront = "CHMF"    'Card processing end command to hold front
Public Const CMD_CardPosition_HoldRear = "CHMR"     'Card processing end command to hold rear
Public Const CMD_HoldingTime_EjectRear = "CIR"      'Holding card time and pull in eject rear command
Public Const CMD_HoldingTime_Inside = "CIS"         'Holding card time and pull in inside unit command
Public Const CMD_Eject_Front = "CEF"                'Eject front command
Public Const CMD_Eject_Rear = "CER"                 'Eject rear command
Public Const CMD_Eject_HoldFront = "CEMF"           'Eject hold front command
Public Const CMD_Eject_HoldRear = "CEMR"            'Eject hold rear command
Public Const CMD_Prohibit = "CP"                    'Prohibit command
Public Const CMD_Reset = "RS"                       'Reset unit command
Public Const CMD_Status = "AP"                      'Status command
Public Const CMD_Shutter = "ST"                     'Shutter open command
Public Const CMD_ICCard_Set = "ICS"                 'IC card set command
Public Const CMD_ICCard_Reset = "ICR"               'IC card reset command
Public Const CMD_LowCo300 = "HCL"                   'Low coercivity set command 1
Public Const CMD_LowCo650 = "HCM"                   'Low coercivity set command 2
Public Const CMD_HiCo = "HCH"                       'Hi coercivity set command
'------------- EEPROM Access Command ----------------------------------------
Public Const CMD_EROM_Password = "NEURON"           'Default password "NEURON"
Public Const CMD_EROM_Open = "EO"                   'EEPROM open command
Public Const CMD_EROM_Close = "EC"                  'EEPROM close command
Public Const CMD_EROM_Read = "ER"                   'EEPROM read command
Public Const CMD_EROM_WriteEnable = "EE"            'EEPROM write enable command
Public Const CMD_EROM_Write = "EW"                  'EEPROM write command
Public Const CMD_EROM_WriteDisable = "ED"           'EEPROM write disable command
'------------- Response ---------------------------------------------------
Public Const RES_Read = "DR"                        'Read response
Public Const RES_Write = "DW"                       'Write response
Public Const RES_ReadWrite_OK = "O"                 'Read or write Ok response code
Public Const RES_ReadWrite_NG = "N"                 'Read or write error response code
Public Const RES_Holding = "DH"                     'Holding event response
Public Const RES_Status = "DA"                      'Status response
Public Const RES_EEPROM = "DE"                      'EEPROM read data response

'---------------------------------------------------------------------------
'       Application messages const declaration
'---------------------------------------------------------------------------
Public Const MSG_Comm_RecDataError = "Communication Data Error" & vbCrLf & "NAK send overflow"
Public Const MSG_Comm_SendDataError = "Communication Data Error. Data send overflow."
Public Const MSG_Comm_BCCError = "   <BCC Error>"
Public Const MSG_Comm_ConfirmData = " Please confirm data box"
Public Const MSG_Comm_CommSetError = "Comm port setting error : "
Public Const MSG_Comm_CommPortClose = "Comm port status : closed"
Public Const MSG_Comm_CommPortOpen = "Comm port status : opened"
Public Const MSG_Comm_CommPortStatus = "Comm port closed! Please open comm port."

'---------------------------------------------------------------------------
'       Response messages const declaration
'---------------------------------------------------------------------------
Public Const MSG_Response_OK = "Command and response OK"
Public Const MSG_Response_Error = "Communication error."
Public Const MSG_Response_CAN = "[CAN] Received"
Public Const MSG_Response_DLE = "[DLE] Received"
Public Const MSG_Response_NAK = "[NAK] Received"
Public Const MSG_Response_ENQ = "[ENQ] Received"
Public Const MSG_Response_EOT = "[EOT] Received"
Public Const MSG_Response_None = "No response"
Public Const MSG_ResponseMode_Read = "Read response"
Public Const MSG_ResponseMode_Write = "Write verify response"
Public Const MSG_ResponseMode_Holding = "Card holding event response"
Public Const MSG_ResponseMode_Status = "Unit status response"
Public Const MSG_ResponseMode_EEPRom = "EEPROM Data response"



